@@ -81,13 +81,9 @@ Get the keys of all color stops.
 
 Cory Watson <gphat@cpan.org>
 
-Infinity Interactive, L<http://www.iinteractive.com>
-
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 by Infinity Interactive, Inc.
-
-L<http://www.iinteractive.com>
+Copyright 2008-2009 by Cory G Watson.
 
 You can redistribute and/or modify this code under the same terms as Perl
 itself.
